# CHANGELOG


## v0.3.0 (2026-05-21)

### Features

- Add require_kong_secret function for header validation
  ([`5acaa9c`](https://github.com/20206205Tech/20206205tech-python-auth/commit/5acaa9ca36fcb9c4f224d35454cbf31cb198feaa))


## v0.2.1 (2026-05-21)

### Bug Fixes

- Environment
  ([`2cb3e7e`](https://github.com/20206205Tech/20206205tech-python-auth/commit/2cb3e7e8e0c7a1d51a74af45a40109d479f1cba8))


## v0.2.0 (2026-05-21)

### Features

- Request-id ([#4](https://github.com/20206205Tech/20206205tech-python-auth/pull/4),
  [`3159080`](https://github.com/20206205Tech/20206205tech-python-auth/commit/315908055c3b31ddbfd3153e6d9cb9d6794814ce))


## v0.1.0 (2026-05-19)

### Features

- Enforce supabase mfa validation on fastapi dependencies
  ([`b82806a`](https://github.com/20206205Tech/20206205tech-python-auth/commit/b82806a92f2d04bd1325904fdc93a29a238e46d6))


## v0.0.0 (2026-05-10)
